require "pathname"
require "cgi"

begin
 require "rubygems"
 gem "ruby-openid", "=1.1.4"
 require 'ruby-openid'
rescue LoadError
 require "openid"
end

class AccountController < ApplicationController

 def login
   openid_url = params[:openid_url]

   if request.post?
     request = consumer.begin(openid_url + ".beta.medpass.pl" )
     case request.status
     when OpenID::SUCCESS
       return_to = url_for(:action => 'complete')
       trust_root = root_url
       url = request.redirect_url(trust_root, return_to)
       redirect_to(url)
       return
     when OpenID::FAILURE
       escaped_url = CGI::escape(openid_url)
       flash[:notice] = "<p>Nieprawidłowa nazwa konta</p>"
     else
       flash[:notice] = "<p>An unknown error occured.</p>"
     end
     redirect_to session[:return_to] || home_index_path
   end
 end

  def complete
    response = consumer.complete(params)
    case response.status
      when OpenID::SUCCESS
        session[:user_medpass_id] = response.identity_url
        redirect_to session[:return_to] || home_index_path
        flash[:notice] = '<p>Zostałeś zalogowany</p>'
        return
      when OpenID::FAILURE
        if response.identity_url
          flash[:notice] = "<p>Verification of #{CGI::escape(response.identity_url)} failed.</p>"
        else
          authorization_failed
        end
      when OpenID::CANCEL
        flash[:notice] = '<p>Verification cancelled.</p>'
      else
        flash[:notice] = 'Unknown response from OpenID server.'
    end
    redirect_to home_index_path
  end


  def logout
    session[:user_medpass_id] = nil
    session[:return_to] = nil
    flash[:notice]  = '<p>Zostałeś wylogowany.</p>'
    redirect_to home_index_path
  end

  def welcome
    redirect_to session.data[:return_to]
  end

  private

  def consumer
    store_dir = Pathname.new(RAILS_ROOT).join('db').join('openid-store')
    store = OpenID::FilesystemStore.new(store_dir)
    return OpenID::Consumer.new(session, store)
  end

  def find_user
    return nil if session[:user_medpass_id].nil?
    User.find(session[:user_medpass_id])
  end

  def authorization_failed
    flash[:notice] = "Autoryzacja nie powiodła się"
  end

end

